@@ -113,32 +113,32 @@ summary(fit.kmib)
 data(icu.pneu)
 
 set.seed(1313)
-dat <- kmi(Surv(entry, exit, status) ~ 1, data = icu.pneu,
-           etype = event, id= id, failcode = 3, nimp = 5)
+dat <- kmi(Surv(start, stop, status) ~ 1, data = icu.pneu,
+           etype = event, id= id, failcode = 2, nimp = 5)
 
 ### add a factor for testing purposes
-icu.pneu$ev.fact <- factor(ifelse(icu.pneu$event == 2, "disch", "death"))
+icu.pneu$ev.fact <- factor(ifelse(icu.pneu$event == 3, "disch", "death"))
 
 icu.pneu$ev <- icu.pneu$event
 icu.pneu$ev[icu.pneu$status == 0] <- 0
 
 set.seed(1313)
-dat2 <- kmi(Surv(entry, exit, ev != 0) ~ 1, data = icu.pneu,
-           etype = ev, id= id, failcode = 3, nimp = 5)
+dat2 <- kmi(Surv(start, stop, ev != 0) ~ 1, data = icu.pneu,
+           etype = ev, id= id, failcode = 2, nimp = 5)
 
 set.seed(1313)
-dat3 <- kmi(Surv(entry, exit, status) ~ 1, data = icu.pneu,
+dat3 <- kmi(Surv(start, stop, status) ~ 1, data = icu.pneu,
             etype = ev.fact, id = id, failcode = "death", nimp = 5)
 
 a <- logical(5)
 for (i in 1:5) a[i] <- all.equal(dat$imputed.data[[i]][, 1], dat2$imputed.data[[i]][, 1])
 a
 
-fit.kmi <- cox.kmi(Surv(entry, exit, event == 3) ~ pneu, dat)
+fit.kmi <- cox.kmi(Surv(start, stop, event == 2) ~ pneu, dat)
 
-fit.kmi2 <- cox.kmi(Surv(entry, exit, ev == 3) ~ pneu, dat2)
+fit.kmi2 <- cox.kmi(Surv(start, stop, ev == 2) ~ pneu, dat2)
 
-fit.kmi3 <- cox.kmi(Surv(entry, exit, ev.fact == "death") ~ pneu, dat3)
+fit.kmi3 <- cox.kmi(Surv(start, stop, ev.fact == "death") ~ pneu, dat3)
 
 all.equal(fit.kmi$coefficients, fit.kmi2$coefficients)
 all.equal(coef(fit.kmi), coef(fit.kmi3))
@@ -153,17 +153,17 @@ fit.kmi3
 ## avec bootstrap
 
 set.seed(598085)
-dat <- kmi(Surv(entry, exit, status) ~ 1, data = icu.pneu,
-           etype = event, id= id, failcode = 3, nimp = 5,
+dat <- kmi(Surv(start, stop, status) ~ 1, data = icu.pneu,
+           etype = event, id= id, failcode = 2, nimp = 5,
            boot = TRUE, nboot = 5)
 
 set.seed(598085)
-dat2 <- kmi(Surv(entry, exit, ev != 0) ~ 1, data = icu.pneu,
-            etype = ev, id= id, failcode = 3, nimp = 5,
+dat2 <- kmi(Surv(start, stop, ev != 0) ~ 1, data = icu.pneu,
+            etype = ev, id= id, failcode = 2, nimp = 5,
             boot = TRUE, nboot = 5)
 
 set.seed(598085)
-dat3 <- kmi(Surv(entry, exit, status) ~ 1, data = icu.pneu,
+dat3 <- kmi(Surv(start, stop, status) ~ 1, data = icu.pneu,
             etype = ev.fact, id = id, failcode = "death", nimp = 5,
             boot = TRUE, nboot = 5)
 
@@ -172,11 +172,11 @@ a <- logical(5)
 for (i in 1:5) a[i] <- all.equal(dat$imputed.data[[i]][, 1], dat2$imputed.data[[i]][, 1])
 a
 
-fit.kmi <- cox.kmi(Surv(entry, exit, event == 3) ~ pneu, dat)
+fit.kmi <- cox.kmi(Surv(start, stop, event == 2) ~ pneu, dat)
 
-fit.kmi2 <- cox.kmi(Surv(entry, exit, ev == 3) ~ pneu, dat2)
+fit.kmi2 <- cox.kmi(Surv(start, stop, ev == 2) ~ pneu, dat2)
 
-fit.kmi3 <- cox.kmi(Surv(entry, exit, ev.fact == "death") ~ pneu, dat3)
+fit.kmi3 <- cox.kmi(Surv(start, stop, ev.fact == "death") ~ pneu, dat3)
 
 all.equal(fit.kmi$coefficients, fit.kmi2$coefficients)
 all.equal(coef(fit.kmi), coef(fit.kmi3))
